class CrudAPI {
  constructor() {
    this.items = JSON.parse(localStorage.getItem('items')) || [];
    this.currentId = this.items.length > 0 ? Math.max(...this.items.map(item => item.id)) + 1 : 1;
    this.form = document.getElementById('itemForm');
    this.itemsList = document.getElementById('itemsList');
    this.init();
  }

  init() {
    this.form.addEventListener('submit', (e) => this.handleSubmit(e));
    this.renderItems();
  }

  handleSubmit(e) {
    e.preventDefault();
    const itemId = document.getElementById('itemId').value;
    const itemName = document.getElementById('itemName').value;
    const itemDescription = document.getElementById('itemDescription').value;

    if (itemId) {
      this.updateItem(parseInt(itemId), itemName, itemDescription);
    } else {
      this.createItem(itemName, itemDescription);
    }

    this.form.reset();
    document.getElementById('itemId').value = '';
  }

  createItem(name, description) {
    const item = {
      id: this.currentId++,
      name,
      description,
      createdAt: new Date().toISOString()
    };
    this.items.push(item);
    this.saveToLocalStorage();
    this.renderItems();
  }

  updateItem(id, name, description) {
    const index = this.items.findIndex(item => item.id === id);
    if (index !== -1) {
      this.items[index] = { ...this.items[index], name, description };
      this.saveToLocalStorage();
      this.renderItems();
    }
  }

  deleteItem(id) {
    this.items = this.items.filter(item => item.id !== id);
    this.saveToLocalStorage();
    this.renderItems();
  }

  editItem(id) {
    const item = this.items.find(item => item.id === id);
    if (item) {
      document.getElementById('itemId').value = item.id;
      document.getElementById('itemName').value = item.name;
      document.getElementById('itemDescription').value = item.description;
    }
  }

  renderItems() {
    this.itemsList.innerHTML = this.items
      .map(item => `
        <div class="item-card">
          <h3>${this.escapeHtml(item.name)}</h3>
          <p>${this.escapeHtml(item.description)}</p>
          <div class="item-actions">
            <button class="btn-edit" onclick="crudApi.editItem(${item.id})">Edit</button>
            <button class="btn-delete" onclick="crudApi.deleteItem(${item.id})">Delete</button>
          </div>
        </div>
      `)
      .join('');
  }

  saveToLocalStorage() {
    localStorage.setItem('items', JSON.stringify(this.items));
  }

  escapeHtml(unsafe) {
    return unsafe
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;")
      .replace(/"/g, "&quot;")
      .replace(/'/g, "&#039;");
  }
}

const crudApi = new CrudAPI();
